@@ -1,5 +1,3 @@
-#!/usr/bin/env python3
-
 from livestreamer.plugins import Plugin, PluginError, NoStreamsError, register_plugin
 from livestreamer.stream import RTMPStream
 from livestreamer.utils import swfverify, urlget
@@ -9,8 +7,7 @@ from livestreamer import options
 import xml.dom.minidom, re, sys, random
 
 class JustinTV(Plugin):
-    StreamInfoURL = "http://usher.justin.tv/find/{0}.xml?type=any&p={1}"
-    StreamInfoURLSub = "http://usher.justin.tv/find/{0}.xml?type=any&p={1}&b_id=true&chansub_guid={2}&private_code=null&group=&channel_subscription={2}"
+    StreamInfoURL = "http://usher.justin.tv/find/{0}.xml?type=any&p={1}&b_id=true&chansub_guid={2}&private_code=null&group=&channel_subscription={2}"
     MetadataURL = "http://www.justin.tv/meta/{0}.xml?on_site=true"
     SWFURL = "http://www.justin.tv/widgets/live_embed_player.swf"
 
@@ -19,11 +16,7 @@ class JustinTV(Plugin):
         return ("justin.tv" in url) or ("twitch.tv" in url)
 
     def _get_channel_name(self, url):
-        data = urlget(url)
-        match = re.search(b"live_facebook_embed_player\.swf\?channel=(\w+)", data)
-
-        if match:
-            return str(match.group(1), "ascii")
+        return url.rstrip("/").rpartition("/")[2]
 
     def _get_metadata(self, channel):
         cookie = options.get("jtvcookie")
@@ -45,7 +38,8 @@ class JustinTV(Plugin):
         metadata = {}
 
         metadata["title"] = self._get_node_if_exists(dom, "title")
-        metadata["chansub_guid"] = self._get_node_if_exists(dom, "chansub_guid")
+        metadata["access_guid"] = self._get_node_if_exists(dom, "access_guid")
+        metadata["login"] = self._get_node_if_exists(dom, "login")
 
         return metadata
 
@@ -68,14 +62,22 @@ class JustinTV(Plugin):
             else:
                 return tag
 
-        metadata = self._get_metadata(channelname)
+
+        chansub = None
+        if options.get("jtvcookie"):
+            self.logger.debug("Attempting to authenticate using cookie")
+
+            metadata = self._get_metadata(channelname)
+            chansub = metadata["access_guid"]
+
+            if "login" in metadata:
+                self.logger.debug("Successfully logged in as {0}", metadata["login"])
+
+
         randomp = int(random.random() * 999999)
+        url = self.StreamInfoURL.format(channelname, randomp, chansub)
 
-        if "chansub_guid" in metadata:
-            url = self.StreamInfoURLSub.format(channelname, randomp, metadata["chansub_guid"])
-        else:
-            url = self.StreamInfoURL.format(channelname, randomp)
-
+        self.logger.debug("Fetching stream info")
         data = urlget(url)
 
         # fix invalid xml
@@ -91,6 +93,7 @@ class JustinTV(Plugin):
 
         nodes = dom.getElementsByTagName("nodes")[0]
 
+        self.logger.debug("Verifying SWF: {0}", self.SWFURL)
         swfhash, swfsize = swfverify(self.SWFURL)
 
         for node in nodes.childNodes:
@@ -106,10 +109,13 @@ class JustinTV(Plugin):
                 "live": True
             })
 
+            sname = clean_tag(node.tagName)
+
             if "token" in info:
                 stream.params["jtv"] = info["token"]
+            else:
+                self.logger.warning("No token found for stream {0}, this stream may fail to play", sname)
 
-            sname = clean_tag(node.tagName)
             streams[sname] = stream
 
         return streams
