@@ -1,7 +1,6 @@
-#!/usr/bin/env python3
+from .compat import urllib
+from .plugins import PluginError
 
-from livestreamer.compat import urllib
-from livestreamer.plugins import PluginError
 import hmac, hashlib, zlib, argparse
 
 SWF_KEY = b"Genuine Adobe Flash Player 001"
@@ -22,7 +21,7 @@ class ArgumentParser(argparse.ArgumentParser):
 def urlopen(url, data=None, timeout=None, opener=None):
     try:
         if opener is not None:
-            fd = opener.open(url)
+            fd = opener.open(url, data, timeout)
         else:
             fd = urllib.urlopen(url, data, timeout)
 
@@ -34,7 +33,7 @@ def urlopen(url, data=None, timeout=None, opener=None):
 
     return fd
 
-def urlget(url, data=None, timeout=None, opener=None):
+def urlget(url, data=None, timeout=15, opener=None):
     fd = urlopen(url, data, timeout, opener)
 
     try:
@@ -58,3 +57,10 @@ def swfverify(url):
 
     return h.hexdigest(), len(swf)
 
+def verifyjson(json, key):
+    if not key in json:
+        raise PluginError(("Missing '{0}' key in JSON").format(key))
+
+    return json[key]
+
+__all__ = ["ArgumentParser", "urlopen", "urlget", "swfverify", "verifyjson"]
